summaryrefslogtreecommitdiff
path: root/tests/x509dn.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/x509dn.c')
-rw-r--r--tests/x509dn.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/x509dn.c b/tests/x509dn.c
index eabad48a89..1c9e7151c5 100644
--- a/tests/x509dn.c
+++ b/tests/x509dn.c
@@ -4,20 +4,20 @@
*
* Author: Simon Josefsson
*
* This file is part of GNUTLS.
*
* GNUTLS is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* GNUTLS is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNUTLS; if not, write to the Free Software Foundation,
* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
*/
@@ -486,7 +486,7 @@ server (void)
if (ret == 0)
{
if (debug)
- success ("server: Peer has closed the GNUTLS connection\n");
+ success ("server: Peer has closed the GnuTLS connection\n");
break;
}
else if (ret < 0)
@@ -4,20 +4,20 @@
* Author: Simon Josefsson
*
- * This file is part of GNUTLS.
+ * This file is part of GnuTLS.
*
@@ -4,20 +4,20 @@
*
- * GNUTLS is free software; you can redistribute it and/or modify it
+ * GnuTLS is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
@@ -4,20 +4,20 @@
* (at your option) any later version.
*
- * GNUTLS is distributed in the hope that it will be useful, but
+ * GnuTLS is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
@@ -4,20 +4,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with GNUTLS; if not, write to the Free Software Foundation,
+ * along with GnuTLS; if not, write to the Free Software Foundation,
* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
*/